# This package has two statistics distributions
    Binomial distribution and Gaussian distribution
    It implements OOP concepts like inheritance, classes, objects and methods.
## 1. A binomial distribution class
    This class claculates and visualizes a binomial distribution

## 2. A gaussian distribution class
    This class calculates and visaulizes a gaussian distribution
